/*
 * Copyright 2018-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.workflow.api;

import java.net.URI;

/**
 * Abstract class for workflow.
 */
public abstract class AbstractWorkflow implements Workflow {

    /**
     * ID of workflow.
     */
    private URI id;

    /**
     * Constructor for AbstractWorkflow.
     * @param id ID of workflow
     */
    protected AbstractWorkflow(URI id) {
        this.id = id;
    }

    @Override
    public URI id() {
        return id;
    }

    @Override
    public WorkflowContext buildContext(Workplace workplace, DataModelTree data) throws WorkflowException {
        return new DefaultWorkflowContext(id, workplace.name(), data);
    }

    @Override
    public WorkflowContext buildSystemContext(Workplace workplace, DataModelTree data) throws WorkflowException {
        return new SystemWorkflowContext(id, workplace.name(), data);
    }
}
